==> hook_event_dispatcher-3.0.0-rc1.tar.gz: hook_event_dispatcher/modules/toolbar_event_dispatcher/tests/src/Kernel/ToolbarEventTest.php <==
<?php

namespace Drupal\Tests\toolbar_event_dispatcher\Kernel;

use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\hook_event_dispatcher\Kernel\ListenerTrait;
use Drupal\toolbar\Element\Toolbar;
use Drupal\toolbar_event_dispatcher\Event\Toolbar\ToolbarAlterEvent;

/**
 * Class ToolbarAlterEventTest.
 *
 * @group hook_event_dispatcher
 * @group toolbar_event_dispatcher
 *
 * @see \toolbar_event_dispatcher_toolbar()
 * @see \toolbar_event_dispatcher_toolbar_alter()
 */
class ToolbarEventTest extends KernelTestBase {

  use ListenerTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'breakpoint',
    'toolbar',
    'user',
    'hook_event_dispatcher',
    'toolbar_event_dispatcher',
  ];

  /**
   * Test the ToolbarEvent and ToolbarAlterEvent.
   *
   * @throws \Exception
   */
  public function testToolbarAlterEvent(): void {
    $this->listen(HookEventDispatcherInterface::TOOLBAR, 'onToolbar');
    $this->listen(HookEventDispatcherInterface::TOOLBAR_ALTER, 'onToolbarAlter');

    $toolbar = Toolbar::preRenderToolbar([]);
    $this->assertArrayHasKey('test', $toolbar);
    $this->assertContains('item', $toolbar['test']);
  }

  /**
   * Callback for ToolbarEvent.
   */
  public function onToolbar() {
  }

  /**
   * Callback for ToolbarAlterEvent.
   *
   * @param \Drupal\toolbar_event_dispatcher\Event\Toolbar\ToolbarAlterEvent $event
   *   The event.
   */
  public function onToolbarAlter(ToolbarAlterEvent $event) {
    $items = &$event->getItems();
    $items['test'] = ['item'];
  }

}

==> hook_event_dispatcher-4.0.0-rc1.tar.gz: hook_event_dispatcher/modules/toolbar_event_dispatcher/tests/src/Kernel/ToolbarEventTest.php <==
<?php

namespace Drupal\Tests\toolbar_event_dispatcher\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\hook_event_dispatcher\Kernel\ListenerTrait;
use Drupal\toolbar\Element\Toolbar;
use Drupal\toolbar_event_dispatcher\Event\Toolbar\ToolbarAlterEvent;
use Drupal\toolbar_event_dispatcher\ToolbarHookEvents;

/**
 * Class ToolbarAlterEventTest.
 *
 * @group hook_event_dispatcher
 * @group toolbar_event_dispatcher
 *
 * @see \toolbar_event_dispatcher_toolbar()
 * @see \toolbar_event_dispatcher_toolbar_alter()
 */
class ToolbarEventTest extends KernelTestBase {

  use ListenerTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'breakpoint',
    'toolbar',
    'user',
    'hook_event_dispatcher',
    'toolbar_event_dispatcher',
  ];

  /**
   * Test the ToolbarEvent and ToolbarAlterEvent.
   *
   * @throws \Exception
   */
  public function testToolbarAlterEvent(): void {
    $this->listen(ToolbarHookEvents::TOOLBAR, 'onToolbar');
    $this->listen(ToolbarHookEvents::TOOLBAR_ALTER, 'onToolbarAlter');

    $toolbar = Toolbar::preRenderToolbar([]);
    $this->assertArrayHasKey('test', $toolbar);
    $this->assertContains('item', $toolbar['test']);
  }

  /**
   * Callback for ToolbarEvent.
   */
  public function onToolbar(): void {
  }

  /**
   * Callback for ToolbarAlterEvent.
   *
   * @param \Drupal\toolbar_event_dispatcher\Event\Toolbar\ToolbarAlterEvent $event
   *   The event.
   */
  public function onToolbarAlter(ToolbarAlterEvent $event): void {
    $items = &$event->getItems();
    $items['test'] = ['item'];
  }

}
